=== added directory 'contrib/apport'
=== added file 'contrib/apport/README'
--- contrib/apport/README	1970-01-01 00:00:00 +0000
+++ contrib/apport/README	2010-01-31 16:32:34 +0000
@@ -0,0 +1,13 @@
+Bazaar supports semi-automatic bug reporting through Apport
+<https://launchpad.net/apport/>.
+
+If apport is not installed, an exception is printed to stderr in the usual way.
+
+For this to work properly it's suggested that two files be installed when a
+package of bzr is installed:
+
+``bzr.conf``
+    into ``/etc/apport/crashdb.conf.d``
+
+``source_bzr.py`` 
+    into ``/usr/share/apport/package-hooks``

=== added file 'contrib/apport/bzr.conf'
--- contrib/apport/bzr.conf	1970-01-01 00:00:00 +0000
+++ contrib/apport/bzr.conf	2010-01-31 16:32:34 +0000
@@ -0,0 +1,6 @@
+bzr = {
+	# most bzr bugs are upstream bugs; file them there
+	'impl': 'launchpad',
+	'project': 'bzr',
+	'bug_pattern_base': 'http://people.canonical.com/~pitti/bugpatterns',
+}

=== added file 'contrib/apport/source_bzr.py'
--- contrib/apport/source_bzr.py	1970-01-01 00:00:00 +0000
+++ contrib/apport/source_bzr.py	2010-01-31 16:32:34 +0000
@@ -0,0 +1,54 @@
+'''apport package hook for Bazaar
+
+(c) 2009 Canonical Ltd.
+Author: Matt Zimmerman <mdz@canonical.com>
+'''
+
+from apport.hookutils import *
+import os
+
+bzr_log = os.path.expanduser('~/.bzr.log')
+dot_bzr = os.path.expanduser('~/.bazaar')
+
+def _add_log_tail(report):
+    # may have already been added in-process
+    if 'BzrLogTail' in report:
+        return
+
+    bzr_log_lines = open(bzr_log).readlines()
+    bzr_log_lines.reverse()
+
+    bzr_log_tail = []
+    blanks = 0
+    for line in bzr_log_lines:
+        if line == '\n':
+            blanks += 1
+        bzr_log_tail.append(line)
+        if blanks >= 2: 
+            break
+
+    bzr_log_tail.reverse()
+    report['BzrLogTail'] = ''.join(bzr_log_tail)
+
+
+def add_info(report):
+
+    _add_log_tail()
+    if 'BzrPlugins' not in report:
+        # may already be present in-process
+        report['BzrPlugins'] = command_output(['bzr', 'plugins', '-v'])
+        
+    # by default assume bzr crashes are upstream bugs; this relies on
+    # having a bzr entry under /etc/apport/crashdb.conf.d/
+    report['CrashDB'] = 'bzr'
+
+    # these may contain some sensitive info (smtp_passwords)
+    # TODO: strip that out and attach the rest
+
+    #attach_file_if_exists(report,
+    #	os.path.join(dot_bzr, 'bazaar.conf', 'BzrConfig')
+    #attach_file_if_exists(report,
+    #	os.path.join(dot_bzr, 'locations.conf', 'BzrLocations')
+
+        
+# vim: expandtabs shiftwidth=4

